package com.ruoyi.system.service.impl;

import java.util.List;
import com.ruoyi.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.system.mapper.ZySlideshowMapper;
import com.ruoyi.system.domain.ZySlideshow;
import com.ruoyi.system.service.IZySlideshowService;

/**
 * 轮播图管理Service业务层处理
 * 
 * @author libao
 * @date 2024-05-24
 */
@Service
public class ZySlideshowServiceImpl implements IZySlideshowService 
{
    @Autowired
    private ZySlideshowMapper zySlideshowMapper;

    /**
     * 查询轮播图管理
     * 
     * @param id 轮播图管理主键
     * @return 轮播图管理
     */
    @Override
    public ZySlideshow selectZySlideshowById(Long id)
    {
        return zySlideshowMapper.selectZySlideshowById(id);
    }

    /**
     * 查询轮播图管理列表
     * 
     * @param zySlideshow 轮播图管理
     * @return 轮播图管理
     */
    @Override
    public List<ZySlideshow> selectZySlideshowList(ZySlideshow zySlideshow)
    {
        return zySlideshowMapper.selectZySlideshowList(zySlideshow);
    }

    /**
     * 新增轮播图管理
     * 
     * @param zySlideshow 轮播图管理
     * @return 结果
     */
    @Override
    public int insertZySlideshow(ZySlideshow zySlideshow)
    {
        zySlideshow.setCreateTime(DateUtils.getNowDate());
        return zySlideshowMapper.insertZySlideshow(zySlideshow);
    }

    /**
     * 修改轮播图管理
     * 
     * @param zySlideshow 轮播图管理
     * @return 结果
     */
    @Override
    public int updateZySlideshow(ZySlideshow zySlideshow)
    {
        zySlideshow.setUpdateTime(DateUtils.getNowDate());
        return zySlideshowMapper.updateZySlideshow(zySlideshow);
    }

    /**
     * 批量删除轮播图管理
     * 
     * @param ids 需要删除的轮播图管理主键
     * @return 结果
     */
    @Override
    public int deleteZySlideshowByIds(Long[] ids)
    {
        return zySlideshowMapper.deleteZySlideshowByIds(ids);
    }

    /**
     * 删除轮播图管理信息
     * 
     * @param id 轮播图管理主键
     * @return 结果
     */
    @Override
    public int deleteZySlideshowById(Long id)
    {
        return zySlideshowMapper.deleteZySlideshowById(id);
    }
}
